package com.example.loginPage.controller;


import com.example.loginPage.model.User;
import com.example.loginPage.service.UserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;
import org.springframework.web.bind.annotation.*;
import reactor.core.publisher.Mono;


@RestController
@RequestMapping("/users")
public class UserController {

    @Autowired
    public UserService userService;

    @Autowired
    private BCryptPasswordEncoder bCryptPasswordEncoder;

    @PostMapping("/login")
    public Mono<ResponseEntity<User>> login(@RequestBody User user) {

        return userService.findByUsername(user.getUsername())
                .filter(dbUser -> bCryptPasswordEncoder.matches(user.getPassword(), dbUser.getPassword()))
                .map(dbUser -> ResponseEntity.ok(dbUser))
                .switchIfEmpty(Mono.error(new RuntimeException("")))
                .defaultIfEmpty(ResponseEntity.badRequest().build());
    }

    @GetMapping("/{username}")
    public Mono<ResponseEntity<User>> findByUsername(@PathVariable String username) {
        return userService.findByUsername(username)
                .map(ResponseEntity::ok)
                .defaultIfEmpty(ResponseEntity.notFound().build());

    }
}


